#!/bin/sh -e

# Move to configuration directory
cd /user/spf2/etc

# Create configuration and version files
ln -fs /user/spf2/etc/config.json /tmp/packet_forwarder.conf
echo spf2 4.0.0-klk7 +hal_libloragw2_4.0.1-klk3 > /tmp/packet_forwarder_version.txt

# Update EUI
EUI=$(awk '{ printf "7276FF00%.8X", $1 }' /sys/fsl_otp/HW_OCOTP_GP1)
CONFIG=$(readlink -f /user/spf2/etc/config.json)
sed -i 's/\(.*"gateway_ID": *"\)[^"]*\(",*\)/\1'${EUI}'\2/' ${CONFIG}

# Open firewall ports
iptables_accept() {
	local PORT=$(sed -n 's/^.*"'${2}'": *\([0-9]*\).*$/\1/p' ${1})
	[ -z "${PORT}" ] && return
	local RULE="OUTPUT -t filter -p udp --dport $PORT -j ACCEPT"
	iptables -C $RULE 2> /dev/null || iptables -A $RULE
	local RULE="INPUT -t filter -p udp --sport $PORT -j ACCEPT"
	iptables -C $RULE 2> /dev/null || iptables -A $RULE
}

iptables_accept /tmp/packet_forwarder.conf serv_port_up
iptables_accept /tmp/packet_forwarder.conf serv_port_down

(
	# Lock on pid file
	exec 8> /var/run/packet_forwarder.pid
	flock -n -x 8
	trap "rm -f /var/run/packet_forwarder.pid" EXIT

	# Start packet forwarder
	/user/spf2/bin/spf2 -g /dev/nmea1 -y 2>&1 | logger -p local1.notice -t spf2 &
	trap "killall -q spf2" INT QUIT TERM

	# Update pid and wait for it
	pidof spf2 >&8
	wait
) &
